Index: wp-includes/option.php
===================================================================
--- wp-includes/option.php	(revision 37802)
+++ wp-includes/option.php	(working copy)
@@ -23,11 +23,12 @@
  *
  * @global wpdb $wpdb WordPress database abstraction object.
  *
  * @param string $option  Name of option to retrieve. Expected to not be SQL-escaped.
  * @param mixed  $default Optional. Default value to return if the option does not exist.
  * @return mixed Value set for the option.
  */
-function get_option( $option, $default = false ) {
+function get_option( $option, $default = false, $cache_only = false ) {
 	global $wpdb;
 
 	$option = trim( $option );
@@ -83,6 +84,9 @@
 			$value = wp_cache_get( $option, 'options' );
 
 			if ( false === $value ) {
+				if ( $cache_only ) {
+					return false;
+				}
 				$row = $wpdb->get_row( $wpdb->prepare( "SELECT option_value FROM $wpdb->options WHERE option_name = %s LIMIT 1", $option ) );
 
 				// Has to be get_row instead of get_var because of funkiness with 0, false, null values
@@ -23,11 +23,12 @@
  * @global wpdb $wpdb WordPress database abstraction object.
  *
- * @param string $option  Name of option to retrieve. Expected to not be SQL-escaped.
- * @param mixed  $default Optional. Default value to return if the option does not exist.
+ * @param string $option     Name of option to retrieve. Expected to not be SQL-escaped.
+ * @param mixed  $default    Optional. Default value to return if the option does not exist.
+ * @param bool   $cache_only If set to true, no query will be done if there is no cached option.
  * @return mixed Value set for the option.
  */
